@@ -52,6 +52,7 @@ import Graphics.Vty.Picture
 import Graphics.Vty.Image
 import Graphics.Vty.Attributes
 
+import Control.Monad (when)
 import Control.Concurrent.STM
 
 import Data.IORef
@@ -78,24 +79,24 @@ import Data.Semigroup ((<>))
 data Vty = Vty
     { -- | Outputs the given 'Picture'.
       update :: Picture -> IO ()
-      -- | Get one 'Event' object, blocking if none are available. This
-      -- will refresh the terminal if the event is a 'EvResize'.
+      -- | Return the next 'Event' or block until one becomes available.
     , nextEvent :: IO Event
+      -- | Non-blocking version of 'nextEvent'.
+    , nextEventNonblocking :: IO (Maybe Event)
       -- | The input interface. See 'Input'.
     , inputIface :: Input
       -- | The output interface. See 'Output'.
     , outputIface :: Output
-      -- | Refresh the display. 'nextEvent' will refresh the display if
-      -- a resize occurs, but this can be used to refresh the display
-      -- explicitly. If other programs output to the terminal and mess
-      -- up the display then the application might want to force a
-      -- refresh using this function.
+      -- | Refresh the display. If other programs output to the terminal
+      -- and mess up the display then the application might want to
+      -- force a refresh using this function.
     , refresh :: IO ()
       -- | Clean up after vty. A call to this function is necessary to
       -- cleanly restore the terminal state before application exit. The
       -- above methods will throw an exception if executed after this is
-      -- executed.
+      -- executed. Idempotent.
     , shutdown :: IO ()
+    , isShutdown :: IO Bool
     }
 
 -- | Create a Vty handle. At most one handle should be created at a time
@@ -116,10 +117,17 @@ mkVty appConfig = do
 intMkVty :: Input -> Output -> IO Vty
 intMkVty input out = do
     reserveDisplay out
+
+    shutdownVar <- atomically $ newTVar False
     let shutdownIo = do
-            shutdownInput input
-            releaseDisplay out
-            releaseTerminal out
+            alreadyShutdown <- atomically $ swapTVar shutdownVar True
+            when (not alreadyShutdown) $ do
+                shutdownInput input
+                releaseDisplay out
+                releaseTerminal out
+
+    let shutdownStatus = atomically $ readTVar shutdownVar
+
     lastPicRef <- newIORef Nothing
     lastUpdateRef <- newIORef Nothing
 
@@ -151,16 +159,24 @@ intMkVty input out = do
             mPic <- readIORef lastPicRef
             maybe (return ()) innerUpdate mPic
 
-    let gkey = do k <- atomically $ readTChan $ _eventChannel input
-                  case k of
-                    (EvResize _ _)  -> displayBounds out
-                                       >>= return . (\(w,h)-> EvResize w h)
-                    _               -> return k
+    let mkResize = uncurry EvResize <$> displayBounds out
+        gkey = do
+            k <- atomically $ readTChan $ _eventChannel input
+            case k of
+                (EvResize _ _)  -> mkResize
+                _ -> return k
+        gkey' = do
+            k <- atomically $ tryReadTChan $ _eventChannel input
+            case k of
+                (Just (EvResize _ _))  -> Just <$> mkResize
+                _ -> return k
 
     return $ Vty { update = innerUpdate
                  , nextEvent = gkey
+                 , nextEventNonblocking = gkey'
                  , inputIface = input
                  , outputIface = out
                  , refresh = innerRefresh
                  , shutdown = shutdownIo
+                 , isShutdown = shutdownStatus
                  }
