@@ -2,6 +2,8 @@
 {-# LANGUAGE StandaloneDeriving #-}
 {-# LANGUAGE GADTs #-}
 {-# LANGUAGE RankNTypes #-}
+{-# LANGUAGE DeriveGeneric #-}
+{-# LANGUAGE DeriveAnyClass #-}
 
 -- | Display attributes
 --
@@ -38,6 +40,7 @@ module Graphics.Vty.Attributes
   , Style
   , withStyle
   , standout
+  , italic
   , underline
   , reverseVideo
   , blink
@@ -60,12 +63,14 @@ module Graphics.Vty.Attributes
   )
 where
 
+import Control.DeepSeq
 import Data.Bits
 #if !(MIN_VERSION_base(4,11,0))
 import Data.Semigroup
 #endif
 import Data.Text (Text)
 import Data.Word
+import GHC.Generics
 
 import Graphics.Vty.Attributes.Color
 import Graphics.Vty.Attributes.Color240
@@ -82,7 +87,7 @@ data Attr = Attr
     , attrForeColor :: !(MaybeDefault Color)
     , attrBackColor :: !(MaybeDefault Color)
     , attrURL :: !(MaybeDefault Text)
-    } deriving ( Eq, Show, Read )
+    } deriving ( Eq, Show, Read, Generic, NFData )
 
 -- This could be encoded into a single 32 bit word. The 32 bit word is
 -- first divided into 4 groups of 8 bits where: The first group codes
@@ -103,14 +108,15 @@ data Attr = Attr
 --      __ - unused
 --
 --  Next is the style flags
---      SURBDO__
+--      SURBDOI_
 --      S - standout
 --      U - underline
 --      R - reverse video
 --      B - blink
 --      D - dim
 --      O - bold
---      __ - unused
+--      I - italic
+--      _ - unused
 --
 --  Then the foreground color encoded into 8 bits.
 --  Then the background color encoded into 8 bits.
@@ -147,6 +153,11 @@ data MaybeDefault v where
     KeepCurrent :: MaybeDefault v
     SetTo :: forall v . ( Eq v, Show v, Read v ) => !v -> MaybeDefault v
 
+instance (NFData v) => NFData (MaybeDefault v) where
+    rnf Default = ()
+    rnf KeepCurrent = ()
+    rnf (SetTo v) = rnf v
+
 deriving instance Eq v => Eq (MaybeDefault v)
 deriving instance Eq v => Show (MaybeDefault v)
 deriving instance (Eq v, Show v, Read v) => Read (MaybeDefault v)
@@ -173,7 +184,7 @@ instance Eq v => Monoid ( MaybeDefault v ) where
 -- if the style attribute should not be applied.
 type Style = Word8
 
--- | The 6 possible style attributes:
+-- | The 7 possible style attributes:
 --
 --      * standout
 --
@@ -187,15 +198,18 @@ type Style = Word8
 --
 --      * bold/bright
 --
+--      * italic
+--
 --  (The invisible, protect, and altcharset display attributes some
 --  terminals support are not supported via VTY.)
-standout, underline, reverseVideo, blink, dim, bold :: Style
+standout, underline, reverseVideo, blink, dim, bold, italic :: Style
 standout        = 0x01
 underline       = 0x02
-reverseVideo   = 0x04
+reverseVideo    = 0x04
 blink           = 0x08
 dim             = 0x10
 bold            = 0x20
+italic          = 0x40
 
 defaultStyleMask :: Style
 defaultStyleMask = 0x00
