@@ -1,8 +1,8 @@
-module Graphics.Vty.Error
-    where
+module Graphics.Vty.Error where
 
 -- | The type of exceptions specific to vty.
 --
--- These have fully qualified names by default since, IMO, exception handling requires this.
+-- These have fully qualified names by default since, IMO, exception
+-- handling requires this.
 data VtyException
     =  VtyFailure String -- ^ Uncategorized failure specific to vty.
