@@ -62,6 +62,8 @@ data DisplayAttrCaps = DisplayAttrCaps
     { setAttrStates :: Maybe CapExpression
     , enterStandout :: Maybe CapExpression
     , exitStandout :: Maybe CapExpression
+    , enterItalic :: Maybe CapExpression
+    , exitItalic :: Maybe CapExpression
     , enterUnderline :: Maybe CapExpression
     , exitUnderline :: Maybe CapExpression
     , enterReverseVideo :: Maybe CapExpression
@@ -227,6 +229,8 @@ currentDisplayAttrCaps ti
     <*> probeCap ti "sgr"
     <*> probeCap ti "smso"
     <*> probeCap ti "rmso"
+    <*> probeCap ti "sitm"
+    <*> probeCap ti "ritm"
     <*> probeCap ti "smul"
     <*> probeCap ti "rmul"
     <*> probeCap ti "rev"
@@ -311,7 +315,7 @@ writeURLEscapes NoLinkChange =
 -- Note that this optimizes for fewer state changes followed by fewer
 -- bytes.
 terminfoWriteSetAttr :: DisplayContext -> TerminfoCaps -> Bool -> FixedAttr -> Attr -> DisplayAttrDiff -> Write
-terminfoWriteSetAttr dc terminfoCaps urlsEnabled prevAttr reqAttr diffs = do
+terminfoWriteSetAttr dc terminfoCaps urlsEnabled prevAttr reqAttr diffs =
     urlAttrs urlsEnabled `mappend` case (foreColorDiff diffs == ColorToDefault) || (backColorDiff diffs == ColorToDefault) of
         -- The only way to reset either color, portably, to the default
         -- is to use either the set state capability or the set default
@@ -332,8 +336,8 @@ terminfoWriteSetAttr dc terminfoCaps urlsEnabled prevAttr reqAttr diffs = do
                                                          $ terminfoCaps
                                                )
                                                (sgrArgsForState state)
-                                  `mappend`
-                                  setColors
+                                  `mappend` setItalics
+                                  `mappend` setColors
         -- Otherwise the display colors are not changing or changing
         -- between two non-default points.
         False -> do
@@ -359,6 +363,7 @@ terminfoWriteSetAttr dc terminfoCaps urlsEnabled prevAttr reqAttr diffs = do
                                                          $ displayAttrCaps terminfoCaps
                                                )
                                                (sgrArgsForState state)
+                                  `mappend` setItalics
                                   `mappend` setColors
     where
         urlAttrs True = writeURLEscapes (urlDiff diffs)
@@ -367,6 +372,15 @@ terminfoWriteSetAttr dc terminfoCaps urlsEnabled prevAttr reqAttr diffs = do
                         False -> ansiColorIndex
                         True -> altColorIndex
         attr = fixDisplayAttr prevAttr reqAttr
+
+        -- italics can't be set via SGR, so here we manually
+        -- apply the enter and exit sequences as needed after
+        -- changing the SGR
+        setItalics
+          | hasStyle (fixedStyle attr) italic
+          , Just sitm <- enterItalic (displayAttrCaps terminfoCaps)
+          = writeCapExpr sitm []
+          | otherwise = mempty
         setColors =
             (case fixedForeColor attr of
                 Just c -> writeCapExpr (setForeColor terminfoCaps)
@@ -434,6 +448,7 @@ data DisplayAttrSeq
 data DisplayAttrState = DisplayAttrState
     { applyStandout :: Bool
     , applyUnderline :: Bool
+    , applyItalic :: Bool
     , applyReverseVideo :: Bool
     , applyBlink :: Bool
     , applyDim :: Bool
@@ -470,6 +485,8 @@ reqDisplayCapSeqFor caps s diffs
         -- set state cap then just use the set state cap.
         ( True, True  ) -> SetState $ stateForStyle s
     where
+        noEnterExitCap ApplyItalic = isNothing $ enterItalic caps
+        noEnterExitCap RemoveItalic = isNothing $ exitItalic caps
         noEnterExitCap ApplyStandout = isNothing $ enterStandout caps
         noEnterExitCap RemoveStandout = isNothing $ exitStandout caps
         noEnterExitCap ApplyUnderline = isNothing $ enterUnderline caps
@@ -482,6 +499,8 @@ reqDisplayCapSeqFor caps s diffs
         noEnterExitCap RemoveDim = True
         noEnterExitCap ApplyBold = isNothing $ enterBoldMode caps
         noEnterExitCap RemoveBold = True
+        enterExitCap ApplyItalic = fromJust $ enterItalic caps
+        enterExitCap RemoveItalic = fromJust $ exitItalic caps
         enterExitCap ApplyStandout = fromJust $ enterStandout caps
         enterExitCap RemoveStandout = fromJust $ exitStandout caps
         enterExitCap ApplyUnderline = fromJust $ enterUnderline caps
@@ -495,6 +514,7 @@ stateForStyle :: Style -> DisplayAttrState
 stateForStyle s = DisplayAttrState
     { applyStandout = isStyleSet standout
     , applyUnderline = isStyleSet underline
+    , applyItalic = isStyleSet italic
     , applyReverseVideo = isStyleSet reverseVideo
     , applyBlink = isStyleSet blink
     , applyDim = isStyleSet dim
@@ -506,10 +526,11 @@ styleToApplySeq :: Style -> [StyleStateChange]
 styleToApplySeq s = concat
     [ applyIfRequired ApplyStandout standout
     , applyIfRequired ApplyUnderline underline
+    , applyIfRequired ApplyItalic italic
     , applyIfRequired ApplyReverseVideo reverseVideo
     , applyIfRequired ApplyBlink blink
     , applyIfRequired ApplyDim dim
-    , applyIfRequired ApplyBlink bold
+    , applyIfRequired ApplyBold bold
     ]
     where
         applyIfRequired op flag
