@@ -1,29 +1,29 @@
 {-# LANGUAGE RankNTypes #-}
 {-# LANGUAGE GADTs #-}
 {-# LANGUAGE RecordWildCards #-}
-{-# LANGUAGE CPP #-}
 {-# LANGUAGE TypeSynonymInstances #-}
 {-# LANGUAGE FlexibleInstances #-}
 {-# LANGUAGE StandaloneDeriving #-}
 {-# LANGUAGE DisambiguateRecordFields #-}
 {-# LANGUAGE NamedFieldPuns #-}
-module Verify ( module Verify
-              , module Control.Applicative
-              , module Control.DeepSeq
-              , module Control.Exception
-              , module Control.Monad
-              , module Test.QuickCheck
-              , module Test.QuickCheck.Modifiers
-              , module Text.Printf
-              , succeeded
-              , failed
-              , monadicIO
-              , liftIO
-              , liftBool
-              , Test(..)
-              , Prop.Result(..)
-              )
-    where
+module Verify
+  ( module Verify
+  , module Control.Applicative
+  , module Control.DeepSeq
+  , module Control.Exception
+  , module Control.Monad
+  , module Test.QuickCheck
+  , module Test.QuickCheck.Modifiers
+  , module Text.Printf
+  , succeeded
+  , failed
+  , monadicIO
+  , liftIO
+  , liftBool
+  , Test(..)
+  , Prop.Result(..)
+  )
+where
 
 import Control.Exception ( bracket, try, SomeException(..) )
 
@@ -35,7 +35,7 @@ import qualified Test.QuickCheck as QC
 import Test.QuickCheck.Modifiers
 import Test.QuickCheck.Property hiding ( Result(..) )
 import qualified Test.QuickCheck.Property as Prop
-import Test.QuickCheck.Monadic ( monadicIO ) 
+import Test.QuickCheck.Monadic ( monadicIO )
 
 import Text.Printf
 
@@ -56,7 +56,7 @@ verify testName p = Test $ TestInstance
     case qcResult of
         QC.Success {..} -> return $ Finished TS.Pass
         QC.Failure {numShrinks,reason} -> return $ Finished
-            $ TS.Fail $ "After " 
+            $ TS.Fail $ "After "
                       ++ show numShrinks ++ " shrinks determined failure to be: "
                       ++ show reason
         _ -> return $ Finished $ TS.Fail "TODO(corey): add failure message"
@@ -85,16 +85,5 @@ instance Arbitrary DoubleColumnChar where
 liftIOResult :: Testable prop => IO prop -> Property
 liftIOResult = ioProperty
 
-#if __GLASGOW_HASKELL__ <= 701
-instance Random Word where
-    random g = 
-        let (i :: Int, g') = random g
-        in (toEnum i, g')
-    randomR (l,h) g =
-        let (i :: Int, g') = randomR (fromEnum l,fromEnum h) g
-        in (toEnum i, g')
-#endif
-
 data Bench where
     Bench :: forall v . NFData v => IO v -> (v -> IO ()) -> Bench
-
