@@ -1,8 +1,8 @@
-{- We setup the environment to envoke certain terminals of interest.
- - This assumes appropriate definitions exist in the current environment for the terminals of
- - interest.
- -}
+-- We setup the environment to envoke certain terminals of interest.
+-- This assumes appropriate definitions exist in the current environment
+-- for the terminals of interest.
 module VerifyOutput where
+
 import Verify
 
 import Graphics.Vty
@@ -12,8 +12,6 @@ import Verify.Graphics.Vty.Output
 
 import Control.Monad
 
-import Data.Default
-
 import qualified System.Console.Terminfo as Terminfo
 import System.Posix.Env
 import System.Posix.IO
@@ -37,11 +35,12 @@ smokeTestTermNonMac termName i = liftIOResult $ do
 smokeTestTerm :: String -> Image -> IO Result
 smokeTestTerm termName i = do
     nullOut <- openFd "/dev/null" WriteOnly Nothing defaultFileFlags
-    t <- outputForConfig $ def { outputFd = Just nullOut, termName = Just termName }
+    t <- outputForConfig $ defaultConfig { outputFd = Just nullOut, termName = Just termName }
     -- putStrLn $ "context color count: " ++ show (contextColorCount t)
     reserveDisplay t
     dc <- displayContext t (100,100)
-    -- always show the cursor to produce tests for terminals with no cursor support.
+    -- always show the cursor to produce tests for terminals with no
+    -- cursor support.
     let pic = (picForImage i) { picCursor = Cursor 0 0 }
     outputPicture dc pic
     setCursorPos t 0 0
