@@ -4,9 +4,11 @@ import Verify.Graphics.Vty.Prelude
 
 import Verify.Graphics.Vty.Picture
 import Verify.Graphics.Vty.Image
+import Verify.Graphics.Vty.Attributes
 import Verify.Graphics.Vty.Span
 import Verify.Graphics.Vty.Output
 import Graphics.Vty.Output
+import Graphics.Vty.Output.Interface
 import Graphics.Vty.Output.Mock
 
 import Graphics.Vty.Debug
@@ -39,27 +41,30 @@ singleTRow :: MockWindow -> Property
 singleTRow (MockWindow w h) = liftIOResult $ do
     (mockData,t) <- mockTerminal (w,h)
     dc <- displayBounds t >>= displayContext t
-    -- create an image that contains just the character T repeated for a single row
+    -- create an image that contains just the character T repeated for a
+    -- single row
     let i = horizCat $ replicate (fromEnum w) (char defAttr 'T')
         pic = (picForImage i) { picBackground = Background 'B' defAttr }
     outputPicture dc pic
-    -- The mock output string that represents the output bytes a single line containing the T
-    -- string: Followed by h - 1 lines of a change to the background attribute and then the
-    -- background character
+    -- The mock output string that represents the output bytes a single
+    -- line containing the T string: Followed by h - 1 lines of a change
+    -- to the background attribute and then the background character
     let expected = "H" ++ "MDA" ++ replicate (fromEnum w) 'T'
                  ++ concat (replicate (fromEnum h - 1) $ "MDA" ++ replicate (fromEnum w) 'B')
     compareMockOutput mockData expected
-    
+
 manyTRows :: MockWindow -> Property
 manyTRows (MockWindow w h) = liftIOResult $ do
     (mockData, t) <- mockTerminal (w,h)
     dc <- displayBounds t >>= displayContext t
-    -- create an image that contains the character 'T' repeated for all the rows
+    -- create an image that contains the character 'T' repeated for all
+    -- the rows
     let i = vertCat $ replicate (fromEnum h) $ horizCat $ replicate (fromEnum w) (char defAttr 'T')
         pic = (picForImage i) { picBackground = Background 'B' defAttr }
     outputPicture dc pic
-    -- The UTF8 string that represents the output bytes is h repeats of a move, 'M', followed by an
-    -- attribute change. 'A', followed by w 'T's
+    -- The UTF8 string that represents the output bytes is h repeats of
+    -- a move, 'M', followed by an attribute change. 'A', followed by w
+    -- 'T's
     let expected = "H" ++ concat (replicate (fromEnum h) $ "MDA" ++ replicate (fromEnum w) 'T')
     compareMockOutput mockData expected
 
@@ -67,12 +72,14 @@ manyTRowsCroppedWidth :: MockWindow -> Property
 manyTRowsCroppedWidth (MockWindow w h) = liftIOResult $ do
     (mockData,t) <- mockTerminal (w,h)
     dc <- displayBounds t >>= displayContext t
-    -- create an image that contains the character 'T' repeated for all the rows
+    -- create an image that contains the character 'T' repeated for all
+    -- the rows
     let i = vertCat $ replicate (fromEnum h) $ horizCat $ replicate (fromEnum w * 2) (char defAttr 'T')
         pic = (picForImage i) { picBackground = Background 'B' defAttr }
     outputPicture dc pic
-    -- The UTF8 string that represents the output bytes is h repeats of a move, 'M', followed by an
-    -- attribute change. 'A', followed by w 'T's
+    -- The UTF8 string that represents the output bytes is h repeats of
+    -- a move, 'M', followed by an attribute change. 'A', followed by w
+    -- 'T's
     let expected = "H" ++ concat (replicate (fromEnum h) $ "MDA" ++ replicate (fromEnum w) 'T')
     compareMockOutput mockData expected
 
@@ -80,12 +87,14 @@ manyTRowsCroppedHeight :: MockWindow -> Property
 manyTRowsCroppedHeight (MockWindow w h) = liftIOResult $ do
     (mockData,t) <- mockTerminal (w,h)
     dc <- displayBounds t >>= displayContext t
-    -- create an image that contains the character 'T' repeated for all the rows
+    -- create an image that contains the character 'T' repeated for all
+    -- the rows
     let i = vertCat $ replicate (fromEnum h * 2) $ horizCat $ replicate (fromEnum w) (char defAttr 'T')
         pic = (picForImage i) { picBackground = Background 'B' defAttr }
     outputPicture dc pic
-    -- The UTF8 string that represents the output bytes is h repeats of a move, 'M', followed by an
-    -- attribute change. 'A', followed by w count 'T's
+    -- The UTF8 string that represents the output bytes is h repeats of
+    -- a move, 'M', followed by an attribute change. 'A', followed by w
+    -- count 'T's
     let expected = "H" ++ concat (replicate (fromEnum h) $ "MDA" ++ replicate (fromEnum w) 'T')
     compareMockOutput mockData expected
 
@@ -97,4 +106,3 @@ tests = return [ verify "unitImageUnitBounds" unitImageUnitBounds
                , verify "manyTRowsCroppedWidth" manyTRowsCroppedWidth
                , verify "manyTRowsCroppedHeight" manyTRowsCroppedHeight
                ]
-
